@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the tools applications of the Qt Toolkit.
@@ -47,7 +47,13 @@
 #include <QtCore/qmetaobject.h>
 #include <QtXml/QDomDocument>
 #include <QtXml/QDomElement>
-#include <QtDBus/QtDBus>
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusConnectionInterface>
+#include <QtDBus/QDBusVariant>
+#include <QtDBus/QDBusArgument>
+#include <QtDBus/QDBusMessage>
+#include <QtDBus/QDBusReply>
 #include <private/qdbusutil_p.h>
 
 QT_BEGIN_NAMESPACE
